@@ -11,19 +11,12 @@ use SSIS::Package::ConnectionManager::MSMQ;
 use SSIS::Package::ConnectionManager::OLEDB;
 use SSIS::Package::ConnectionManager::SMOServer;
 use SSIS::Package::ConnectionManager::SMTP;
-use SSIS::Package::ConnectionManager::ADO;
-use SSIS::Package::ConnectionManager::MSOLAP100;
-use SSIS::Package::ConnectionManager::CACHE;
-use SSIS::Package::ConnectionManager::FTP;
-use SSIS::Package::ConnectionManager::HTTP;
-use SSIS::Package::ConnectionManager::MULTIFLATFILE;
-use SSIS::Package::ConnectionManager::MULTIFILE;
-use SSIS::Package::ConnectionManager::ODBC;
-use SSIS::Package::ConnectionManager::WMI;
-use SSIS::Package::ConnectionManager::SQLMOBILE;
 
 
 use XML::Simple ; #qw(:strict);
+#use XML::LibXML;
+use XML::CompactTree::XS;
+use XML::LibXML::Reader;
 
 use Data::Dumper;
 use Data::Printer;
@@ -40,6 +33,9 @@ Version 0.01
 
 =cut
 
+our $VERSION = '0.01';
+
+
 
 use autodie qw(:all);
 
@@ -50,59 +46,54 @@ sub make {
     my ($self) = shift;
     croak 'Invalid call' unless defined $self;
  
-    my $rh_args         = $_[0];
-    my $objType         = $rh_args->{type} ;
-    my $objectData      = $rh_args->{objectData} ;
-
+    my $xml = $_[0] ;
+#warn Dumper $xml;    
+    my @type = grep { $_->{'DTS:Name'} eq 'CreationName' }  @{$xml->{'DTS:Property'}};
+#warn Dumper @type;
+    
+    my $connectManager ;
+    my $objType = $type[0]->{content};
+    
     # fix up crappy invalid character in .net name;
     if ($objType =~ m{ \A ADO\.NET}x )  { $objType = "ADONET" } ;
     
-    my $connectManager;
- 
-    if ($objType =~ m{\A (ADO|ADONET|CACHE|EXCEL|FILE|FTP|FLATFILE|HTTP|MSMQ|MSOLAP100|MULTIFILE|MULTIFLATFILE|ODBC|OLEDB|SMOServer|SMTP|SQLMOBILE|WMI) \z}x ) {
-
-        my @connstr;
-        my $connstr;
-        my @name;
-        my $name;
-
-        if ($objType eq 'FTP' ) {
-            @connstr = grep { $_->{'DTS:Name'} eq 'ConnectionString' }  @{$objectData->{'DTS:ConnectionManager'}->{'DTS:FtpConnection'}->{'DTS:Property'}};
-            $connstr = $connstr[0]->{content};
+    if ($objType =~ m{\A(ADONET|EXCEL|FILE|FLATFILE|MSMQ|OLEDB|SMOServer|SMTP)\z} ) {
+            my @connstr = grep { $_->{'DTS:Name'} eq 'ConnectionString' }  @{$xml->{'DTS:ObjectData'}->{'DTS:ConnectionManager'}->{'DTS:Property'}};
+            my $connstr = $connstr[0]->{content};
+            my @name    = grep { $_->{'DTS:Name'} eq 'ObjectName' }        @{$xml->{'DTS:Property'}};
+            my $name    = $name[0]->{content};
+#warn Dumper $connstr, $name ;
+    
+        if ($objType eq "ADONET" ) {
+            $connectManager = "SSIS::Package::ConnectionManager::${objType}"->new( { 'Name' => $name, 'ConnectionString' => $connstr } );    
         }
-        elsif ($objType eq 'HTTP' ) {
-            @connstr = grep { $_->{'DTS:Name'} eq 'ConnectionString' }  @{$objectData->{'DTS:ConnectionManager'}->{'DTS:HttpConnection'}->{'DTS:Property'}};
-            $connstr = $connstr[0]->{content};
+        if ($objType eq "EXCEL" ) {
+            $connectManager = "SSIS::Package::ConnectionManager::${objType}"->new( { 'Name' => $name, 'ConnectionString' => $connstr } );    
         }
-        elsif ($objType eq 'WMI' ) {
-            $connstr = $objectData->{'WmiConnectionManager'}->{'ConnectionString'};
+        if ($objType eq "FILE" ) {
+            $connectManager = "SSIS::Package::ConnectionManager::${objType}"->new( { 'Name' => $name, 'ConnectionString' => $connstr } );    
         }
-        elsif ($objType eq "MSMQ" ) {
-            $connstr        = $objectData->{'MsmqConnectionManager'}->{'ConnectionString'};
+        if ($objType eq "FLATFILE" ) {
+#warn Dumper $xml;
+            $connectManager = "SSIS::Package::ConnectionManager::${objType}"->new( { 'Name' => $name, 'ConnectionString' => $connstr } );    
         }
-        elsif ($objType eq "SMOServer" ) {
-            $connstr        = $objectData->{'SMOServerConnectionManager'}->{'ConnectionString'};
+        if ($objType eq "MSMQ" ) {
+#warn Dumper $xml;
+            $connstr        = $xml->{'DTS:ObjectData'}->{'MsmqConnectionManager'}->{'ConnectionString'};
+            $connectManager = "SSIS::Package::ConnectionManager::${objType}"->new( { 'Name' => $name, 'ConnectionString' => $connstr } );    
         }
-        elsif ($objType eq "SMTP" ) {
-            $connstr        = $objectData->{'SmtpConnectionManager'}->{'ConnectionString'};
+        if ($objType eq "OLEDB" ) {
+            $connectManager = "SSIS::Package::ConnectionManager::${objType}"->new( { 'Name' => $name, 'ConnectionString' => $connstr } );    
         }
-        else {
-            if ( ref($objectData->{'DTS:ConnectionManager'}->{'DTS:Property'}) eq 'ARRAY' ) {
-                @connstr = grep { $_->{'DTS:Name'} eq 'ConnectionString' }  @{$objectData->{'DTS:ConnectionManager'}->{'DTS:Property'}};
-                $connstr = $connstr[0]->{content};
-            } 
-            else {
-                $connstr = $objectData->{'DTS:ConnectionManager'}->{'DTS:Property'}->{content};
-            }
+        if ($objType eq "SMOServer" ) {
+#warn Dumper $xml;        
+            $connstr        = $xml->{'DTS:ObjectData'}->{'SMOServerConnectionManager'}->{'ConnectionString'};
+            $connectManager = "SSIS::Package::ConnectionManager::${objType}"->new( { 'Name' => $name, 'ConnectionString' => $connstr } );    
+        }
+        if ($objType eq "SMTP" ) {
+            $connstr        = $xml->{'DTS:ObjectData'}->{'SmtpConnectionManager'}->{'ConnectionString'};
+            $connectManager = "SSIS::Package::ConnectionManager::${objType}"->new( { 'Name' => $name, 'ConnectionString' => $connstr } );    
         }
-
-        my @valrefs = map { ( $_->{'DTS:Name'},$_->{'content'} ) ;} @{$rh_args->{properties}}; 
-        
-        # add connection string
-        push @valrefs, 'ConnectionString' , $connstr ;
-
-        $connectManager = "SSIS::Package::ConnectionManager::${objType}"->new( { (@valrefs) } );    
-
     }
     else {
         croak "Unknown connection type $objType.";
