@@ -1,10 +1,3 @@
-has 'TaskContact' => (
-    is  => 'ro'
-,   isa => 'Maybe[Str]'
-,   required => 1
-);
-
-
 package SSIS::Package::DTSTask::ExpressionTask;
 
 use 5.010;
@@ -22,7 +15,7 @@ Version 0.01
 
 =cut
 
-#our $VERSION = '0.01';
+our $VERSION = '0.01';
 
 
 
