@@ -15,13 +15,7 @@ Version 0.01
 
 =cut
 
-#our $VERSION = '0.01';
-
-has 'MaxConcurrent' => (
-    is  => 'ro'
-,   isa => 'Num'
-,   required => 1
-);
+our $VERSION = '0.01';
 
 
 
